@@ -594,16 +594,77 @@ pv.rpv <- function(tab, alpha) {
   t.npv <- log(rel.npv) / se.log.rel.npv
   p.value <- 2*pnorm(-abs(t.npv))
   npv <- list(npv.1, npv.2, rel.npv, se.log.rel.npv, lcl, ucl, t.npv, p.value)
+  sigma.pn <- 
+    (((p1+p2)*p6)/((p5+p6)*(p1+p2+p5+p6)*(p2+p4+p6+p8))) +
+    (((p6+p8)*p2)/((p2+p4)*(p1+p2+p5+p6)*(p2+p4+p6+p8))) +
+    (((p1+p3)*p7)/((p5+p7)*(p1+p3+p5+p7)*(p3+p4+p7+p8))) +
+    (((p7+p8)*p3)/((p3+p4)*(p1+p3+p5+p7)*(p3+p4+p7+p8)))
+  Sigma <- matrix(c(sigma2.p, sigma.pn, sigma.pn, sigma2.n), ncol = 2,
+                  dimnames = list(c("log.rppv", "log.rnpv"),
+                                  c("log.rppv", "log.rnpv")))/N
   # results
   method <- "relative predictive values (rpv)"
-  results <- list(ppv,npv,method,alpha)
-  names(results) <- c("ppv","npv","method","alpha")
+  results <- list(ppv,npv,Sigma,method,alpha)
+  names(results) <- c("ppv","npv","Sigma","method","alpha")
   names(results$ppv) <- c("test1","test2","rppv","se.log.rppv","lcl.rppv","ucl.rppv","test.statistic","p.value")
   names(results$npv) <- c("test1","test2","rnpv","se.log.rnpv","lcl.rnpv","ucl.rnpv","test.statistic","p.value")
   return(results)
 }
 
-
+# --------------------------------------------------------
+# ellipse.pv.rpv
+# --------------------------------------------------------
+#' Elliptical joint confidence region for relative positive and
+#' negative predictive value
+#' 
+#' @description Returns a 100(1-alpha)\% elliptical joint confidence region for the parameter
+#' vector \{log(relative positive predictive value), log(relative negative predictive value)\}.
+#' 
+#' @usage ellipse.pv.rpv(x, alpha = 0.05, npoints = 100, exponentiate = FALSE)
+#' 
+#' @param x an object returned by the \code{pv.rpv} function.
+#' @param alpha significance level alpha used to compute the 100(1-alpha)\% region. The default is 0.05, for a 95\% region.
+#' @param npoints the number of points used in the ellipse. Default is 100.
+#' @param exponentiate a logical value indicating whether or not to exponentiate the values for the centre
+#' of the ellipse and for the the ellipsoidal outline. Defaults to FALSE.
+#' 
+#' @returns A list containing:
+#' \item{centre}{the centre of the ellipse.}
+#' \item{ellipse}{an \code{npoints} x 2 matrix with the x and y coordinates for
+#' the ellipsoidal outline. Suitable for \code{plot}-ing.}
+#' 
+#' @references Moskowitz, C.S., and Pepe, M.S. (2006). Comparing the predictive values of diagnostic tests: sample size and analysis for paired study designs. \emph{Clin Trials}, 3(3):272-9.
+#' 
+#' @seealso \code{pv.rpv} and \code{ellipse::ellipse}.
+#' 
+#' @examples
+#' data(Paired1) # Hypothetical study data
+#' ftable(Paired1)
+#' paired.layout <- tab.paired(d=d, y1=y1, y2=y2, data=Paired1)
+#' paired.layout 
+#' rpv.results <- pv.rpv(paired.layout)
+#' ellipse.data <- ellipse.pv.rpv(rpv.results)
+#' if(interactive()){
+#'   plot(ellipse.data$ellipse, type = "l", ylim = c(-0.25, 0.40), xlim = c(-0.25, 0.20))
+#'   points(ellipse.data$centre[1], ellipse.data$centre[2], col = "red", pch = 19)
+#'   abline(h = 0, v = 0, lty = 3)
+#' }
+#' 
+ellipse.pv.rpv <- function(x, alpha = 0.05, npoints = 100, exponentiate = FALSE) {
+  if (!x$method == "relative predictive values (rpv)")
+    stop("x must be an object from 'pr.rpv()' function")
+  centre <- c(log.rppv = log(x$ppv$rppv), 
+              log.rnpv = log(x$npv$rnpv))
+  Sigma <- x$Sigma
+  ellipse <- ellipse::ellipse(x = Sigma , centre = centre, level = 1-alpha, npoints = npoints)
+  ret <- list(centre = centre, ellipse = ellipse)
+  if (isTRUE(exponentiate)) {
+    ret <- lapply(ret, exp)
+    names(ret$centre) <- sapply(names(ret$centre), function(x) gsub("log.", "", x))
+    colnames(ret$ellipse) <- sapply(colnames(ret$ellipse), function(x) gsub("log.", "", x))
+  }
+  return(ret)
+}
 # --------------------------------------------------------
 # End 
 # --------------------------------------------------------
